@@ -1,7 +1,7 @@
 from smartrent.api import async_login
 from smartrent.lock import DoorLock
 from smartrent.sensor import LeakSensor
-from smartrent.switch import BinarySwitch
+from smartrent.switch import BinarySwitch, MultilevelSwitch
 from smartrent.thermostat import Thermostat
 from smartrent.utils import Client
 
@@ -10,6 +10,7 @@ __all__ = [
     "DoorLock",
     "Thermostat",
     "LeakSensor",
+    "MultilevelSwitch",
     "BinarySwitch",
     "Client",
 ]
